# Pyenc

# Install

````
pkg up -y
````

````
pkg i python -y
````

````
pip install pyenc
````

# Run

````
enc
````


Use Letest Termux Version 0.118.0 (118) : <a href="https://f-droid.org/repo/com.termux_118.apk">DOWNLOAD TERMUX v118</a>

## Our Social Media

<div id="badges">
  <a href="https://www.facebook.com/groups/2078563798832259/?ref=share">
    <img src="https://img.shields.io/badge/Facebook-blue?style=for-the-badge&logo=facebook&logoColor=white" alt="Twitter Badge"/>
  </a>
 
  
  <a href="https://github.com/Devs-Community04">
    <img src="https://img.shields.io/badge/Github-blue?style=for-the-badge&logo=github&logoColor=white" alt="Twitter Badge"/>
  </a>
  <a href="https://facebook.com/community.dev.04">
    <img src="https://img.shields.io/badge/Facebook-blue?style=for-the-badge&logo=facebook&logoColor=white" alt="Twitter Badge"/>
    
  </a>
</div>
<br>
Developed By <a href=https://facebook.com/AKX.THE.PSYCHO>Mohammad Alamin</a>